@@ -14,15 +14,11 @@ class VideoDataset(Dataset):
     key example: train/00001/0001/im1.png
     """
 
-    def __init__(self, video_reader: VideoReader, num_frames=7, random_reverse=True):
+    def __init__(self, video_reader: VideoReader, num_frames=7):
         super(VideoDataset, self).__init__()
         self.reader = video_reader
         self.num_frames = num_frames
 
-        # temporal augmentation
-        self.random_reverse = random_reverse
-        logger.info('Temporal augmentation with random reverse is {}.'.format(self.random_reverse))
-
         self.video_list = self.reader.list_videos()
         self.len = sum([len(video) // num_frames for video in self.video_list])
 
@@ -42,6 +38,4 @@ class VideoDataset(Dataset):
                 break
             else:
                 frame_index = frame_index - (len(self.video_list[i]) - len(self.video_list[i]) % self.num_frames)
-        if self.random_reverse and random.random() < 0.5:
-            frames.reverse()
         return frames
